---
title: <span class="badge builder"></span> ScaleDimensionConfig
---
# <span class="badge builder"></span> ScaleDimensionConfig

## Constructor

```python
ScaleDimensionConfig()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> common.ScaleDimensionConfig
```

### <span class="badge object-method"></span> field

fixed: T -- will be added by each element

```python
def field(field: str) -> typing.Self
```

### <span class="badge object-method"></span> fixed

```python
def fixed(fixed: float) -> typing.Self
```

### <span class="badge object-method"></span> max_val

```python
def max_val(max_val: float) -> typing.Self
```

### <span class="badge object-method"></span> min_val

```python
def min_val(min_val: float) -> typing.Self
```

### <span class="badge object-method"></span> mode

| *"linear"

```python
def mode(mode: common.ScaleDimensionMode) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ScaleDimensionConfig](./object-ScaleDimensionConfig.md)
